==> com.liferay.frontend.editor.tinymce.web-4.0.5.jar: META-INF/resources/_diffs/langs/sr.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('sr', {
	Cut: 'Iseci',
	'Header 2': 'Zaglavlje 2',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		'Va\u0161 pretra\u017eiva\u010d nepodr\u017eava direktan pristup prenosu.Koristite Ctrl+X/C/V pre\u010dice na tastaturi',
	Div: 'Div',
	Paste: 'Nalepi',
	Close: 'Zatvori',
	'Font Family': 'Vrsta fonta',
	Pre: 'Pre',
	'Align right': 'Poravnano  desno',
	'New document': 'Novi dokument',
	Blockquote: 'Navodnici',
	'Numbered list': 'Numerisana lista',
	'Increase indent': 'Pove\u0107aj uvla\u010denje',
	Formats: 'Formatiraj',
	Headers: 'Zaglavlje',
	'Select all': 'Obele\u017ei sve',
	'Header 3': 'Zaglavlje 3',
	Blocks: 'Blokovi',
	Undo: 'Nazad',
	Strikethrough: 'Precrtan',
	'Bullet list': 'Lista nabrajanja',
	'Header 1': 'Zaglavlje 1',
	Superscript: 'Natpis',
	'Clear formatting': 'Brisanje formatiranja',
	'Font Sizes': 'Veli\u010dine fontova',
	Subscript: 'Potpisan',
	'Header 6': 'Zaglavlje 6',
	Redo: 'Napred',
	Paragraph: 'Paragraf',
	Ok: 'Ok',
	Bold: 'Podebljan',
	Code: 'Kod',
	Italic: 'isko\u0161en',
	'Align center': 'Poravnano centar',
	'Header 5': 'Zaglavlje 5',
	'Decrease indent': 'Smanji uvla\u010denje',
	'Header 4': 'Zaglavlje 4',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		'Nalepiti je sada u obi\u010dnom text modu.Sadr\u017eaj \u0107e biti nalepljen kao obi\u010dan tekst dok ne ugasite ovu opciju.',
	Underline: 'Podvu\u010den',
	Cancel: 'Opozovi',
	Justify: 'Poravnanje',
	Inline: 'U liniji',
	Copy: 'Kopiraj',
	'Align left': 'Poravnano levo',
	'Visual aids': 'Vizuelna pomagala',
	'Lower Greek': 'Ni\u017ei gr\u010dki',
	Square: 'Kvadrat',
	Default: 'Podrazumevano',
	'Lower Alpha': 'Donja Alpha',
	Circle: 'Krug',
	Disc: 'Disk',
	'Upper Alpha': 'Gornji Alpha',
	'Upper Roman': 'Gornji Roman',
	'Lower Roman': 'Donji Roman',
	Name: 'Ime',
	Anchor: 'Sidro',
	'You have unsaved changes are you sure you want to navigate away?':
		'Imate nesa\u010duvane promene dali ste sigurni da \u017eelite da iza\u0111ete?',
	'Restore last draft': 'Vrati  poslednji nacrt',
	'Special character': 'Specijalni karakter',
	'Source code': 'Izvorni kod',
	'Right to left': 'Sa desne na levu',
	'Left to right': 'Sa leve na desnu',
	Emoticons: 'Smajliji',
	Robots: 'Roboti',
	'Document properties': 'Postavke dokumenta',
	Title: 'Naslov',
	Keywords: 'Klju\u010dne re\u010di',
	Encoding: 'Kodiranje',
	Description: 'Opis',
	Author: 'Autor',
	Fullscreen: 'Pun ekran',
	'Horizontal line': 'Horizontalna linija',
	'Horizontal space': 'Horizontalni razmak',
	'Insert/edit image': 'Ubaci/Promeni sliku',
	General: 'Op\u0161te',
	Advanced: 'Napredno',
	Source: 'Izvor',
	Border: 'Okvir',
	'Constrain proportions': 'Ograni\u010dene proporcije',
	'Vertical space': 'Vertikalni razmak',
	'Image description': 'Opis slike',
	Style: 'Stil',
	Dimensions: 'Dimenzije',
	'Insert image': 'Ubaci sliku',
	'Insert date/time': 'Ubaci datum/vreme',
	'Remove link': 'Ukloni link',
	Url: 'Url',
	'Text to display': 'Tekst za prikaz',
	Anchors: 'sidro',
	'Insert link': 'Ubaci vezu',
	'New window': 'Novi prozor',
	None: 'Ni\u0161ta',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?',
	Target: 'Meta',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?',
	'Insert/edit link': 'Ubaci/promeni vezu',
	'Insert/edit video': 'Ubaci/promeni video',
	Poster: 'Poster',
	'Alternative source': 'Alternativni izvor',
	'Paste your embed code below:': 'Nalepite ugra\u0111eni kod ispod:',
	'Insert video': 'Ubaci video',
	Embed: 'Ugra\u0111eno',
	'Nonbreaking space': 'bez ramaka',
	'Page break': 'Lomljenje stranice',
	'Paste as text': 'Nalepi kao tekst',
	Preview: 'Pregled',
	Print: '\u0160tampanje',
	Save: 'Sa\u010duvati',
	'Could not find the specified string.':
		'Nije mogu\u0107e prona\u0107i navedeni niz.',
	Replace: 'Zameni',
	Next: 'Slede\u0107i',
	'Whole words': 'Cele re\u010di',
	'Find and replace': 'Na\u0111i i zameni',
	'Replace with': 'Zameni sa',
	Find: 'Na\u0111i',
	'Replace all': 'Zameni sve',
	'Match case': 'Predmet za upore\u0111ivanje',
	Prev: 'Prethodni',
	Spellcheck: 'Provera pravopisa',
	Finish: 'Kraj',
	'Ignore all': 'Ignori\u0161i sve',
	Ignore: 'ignori\u0161i',
	'Insert row before': 'Ubaci red pre',
	Rows: 'Redovi',
	Height: 'Visina',
	'Paste row after': 'Nalepi red posle',
	Alignment: 'Svrstavanje',
	'Column group': 'Grupa kolone',
	Row: 'Red',
	'Insert column before': 'Ubaci kolonu pre',
	'Split cell': 'Razdvoji \u0107elije',
	'Cell padding': 'Razmak \u0107elije',
	'Cell spacing': 'Prostor \u0107elije',
	'Row type': 'Tip reda',
	'Insert table': 'ubaci tabelu',
	Body: 'Telo',
	Caption: 'Natpis',
	Footer: 'Podno\u017eje',
	'Delete row': 'Obri\u0161i red',
	'Paste row before': 'Nalepi red pre',
	Scope: 'Obim',
	'Delete table': 'Obri\u0161i tabelu',
	'Header cell': 'Visina \u0107elije',
	Column: 'Kolona',
	Cell: '\u0106elija',
	Header: 'Zaglavlje',
	'Cell type': 'Tip \u0107elije',
	'Copy row': 'Kopiraj red',
	'Row properties': 'Postavke reda',
	'Table properties': 'Postavke tabele',
	'Row group': 'Grupa reda',
	Right: 'Desno',
	'Insert column after': 'Ubaci kolonu posle',
	Cols: 'Kolone',
	'Insert row after': 'Ubaci red posle',
	Width: '\u0160irina',
	'Cell properties': 'Postavke \u0107elije',
	Left: 'Levo',
	'Cut row': 'Iseci red',
	'Delete column': 'Obri\u0161i kolonu',
	Center: 'Centar',
	'Merge cells': 'Spoji \u0107elije',
	'Insert template': 'Ubaci \u0161ablon',
	Templates: '\u0160abloni',
	'Background color': 'Boja pozadine',
	'Text color': 'Boja tekst',
	'Show blocks': 'Prikaz blokova',
	'Show invisible characters': 'Prika\u017ei nevidljive karaktere',
	'Words: {0}': 'Re\u010di:{0}',
	Insert: 'Umetni',
	File: 'Datoteka',
	Edit: 'Ure\u0111ivanje',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		'Oboga\u0107en tekst. Pritisni te ALT-F9 za meni.Pritisnite ALT-F10 za traku sa alatkama.Pritisnite ALT-0 za pomo\u0107',
	Tools: 'Alatke',
	View: 'Prikaz',
	Table: 'Tabela',
	Format: 'Format',
});

==> com.liferay.frontend.editor.tinymce.web-5.0.15.jar: META-INF/resources/_diffs/langs/sr.js <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

tinymce.addI18n('sr', {
	'Cut': 'Iseci',
	'Header 2': 'Zaglavlje 2',
	"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X/C/V keyboard shortcuts instead.":
		'Va\u0161 pretra\u017eiva\u010d nepodr\u017eava direktan pristup prenosu.Koristite Ctrl+X/C/V pre\u010dice na tastaturi',
	'Div': 'Div',
	'Paste': 'Nalepi',
	'Close': 'Zatvori',
	'Font Family': 'Vrsta fonta',
	'Pre': 'Pre',
	'Align right': 'Poravnano  desno',
	'New document': 'Novi dokument',
	'Blockquote': 'Navodnici',
	'Numbered list': 'Numerisana lista',
	'Increase indent': 'Pove\u0107aj uvla\u010denje',
	'Formats': 'Formatiraj',
	'Headers': 'Zaglavlje',
	'Select all': 'Obele\u017ei sve',
	'Header 3': 'Zaglavlje 3',
	'Blocks': 'Blokovi',
	'Undo': 'Nazad',
	'Strikethrough': 'Precrtan',
	'Bullet list': 'Lista nabrajanja',
	'Header 1': 'Zaglavlje 1',
	'Superscript': 'Natpis',
	'Clear formatting': 'Brisanje formatiranja',
	'Font Sizes': 'Veli\u010dine fontova',
	'Subscript': 'Potpisan',
	'Header 6': 'Zaglavlje 6',
	'Redo': 'Napred',
	'Paragraph': 'Paragraf',
	'Ok': 'Ok',
	'Bold': 'Podebljan',
	'Code': 'Kod',
	'Italic': 'isko\u0161en',
	'Align center': 'Poravnano centar',
	'Header 5': 'Zaglavlje 5',
	'Decrease indent': 'Smanji uvla\u010denje',
	'Header 4': 'Zaglavlje 4',
	'Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.':
		'Nalepiti je sada u obi\u010dnom text modu.Sadr\u017eaj \u0107e biti nalepljen kao obi\u010dan tekst dok ne ugasite ovu opciju.',
	'Underline': 'Podvu\u010den',
	'Cancel': 'Opozovi',
	'Justify': 'Poravnanje',
	'Inline': 'U liniji',
	'Copy': 'Kopiraj',
	'Align left': 'Poravnano levo',
	'Visual aids': 'Vizuelna pomagala',
	'Lower Greek': 'Ni\u017ei gr\u010dki',
	'Square': 'Kvadrat',
	'Default': 'Podrazumevano',
	'Lower Alpha': 'Donja Alpha',
	'Circle': 'Krug',
	'Disc': 'Disk',
	'Upper Alpha': 'Gornji Alpha',
	'Upper Roman': 'Gornji Roman',
	'Lower Roman': 'Donji Roman',
	'Name': 'Ime',
	'Anchor': 'Sidro',
	'You have unsaved changes are you sure you want to navigate away?':
		'Imate nesa\u010duvane promene dali ste sigurni da \u017eelite da iza\u0111ete?',
	'Restore last draft': 'Vrati  poslednji nacrt',
	'Special character': 'Specijalni karakter',
	'Source code': 'Izvorni kod',
	'Right to left': 'Sa desne na levu',
	'Left to right': 'Sa leve na desnu',
	'Emoticons': 'Smajliji',
	'Robots': 'Roboti',
	'Document properties': 'Postavke dokumenta',
	'Title': 'Naslov',
	'Keywords': 'Klju\u010dne re\u010di',
	'Encoding': 'Kodiranje',
	'Description': 'Opis',
	'Author': 'Autor',
	'Fullscreen': 'Pun ekran',
	'Horizontal line': 'Horizontalna linija',
	'Horizontal space': 'Horizontalni razmak',
	'Insert/edit image': 'Ubaci/Promeni sliku',
	'General': 'Op\u0161te',
	'Advanced': 'Napredno',
	'Source': 'Izvor',
	'Border': 'Okvir',
	'Constrain proportions': 'Ograni\u010dene proporcije',
	'Vertical space': 'Vertikalni razmak',
	'Image description': 'Opis slike',
	'Style': 'Stil',
	'Dimensions': 'Dimenzije',
	'Insert image': 'Ubaci sliku',
	'Insert date/time': 'Ubaci datum/vreme',
	'Remove link': 'Ukloni link',
	'Url': 'Url',
	'Text to display': 'Tekst za prikaz',
	'Anchors': 'sidro',
	'Insert link': 'Ubaci vezu',
	'New window': 'Novi prozor',
	'None': 'Ni\u0161ta',
	'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?':
		'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?',
	'Target': 'Meta',
	'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?':
		'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?',
	'Insert/edit link': 'Ubaci/promeni vezu',
	'Insert/edit video': 'Ubaci/promeni video',
	'Poster': 'Poster',
	'Alternative source': 'Alternativni izvor',
	'Paste your embed code below:': 'Nalepite ugra\u0111eni kod ispod:',
	'Insert video': 'Ubaci video',
	'Embed': 'Ugra\u0111eno',
	'Nonbreaking space': 'bez ramaka',
	'Page break': 'Lomljenje stranice',
	'Paste as text': 'Nalepi kao tekst',
	'Preview': 'Pregled',
	'Print': '\u0160tampanje',
	'Save': 'Sa\u010duvati',
	'Could not find the specified string.':
		'Nije mogu\u0107e prona\u0107i navedeni niz.',
	'Replace': 'Zameni',
	'Next': 'Slede\u0107i',
	'Whole words': 'Cele re\u010di',
	'Find and replace': 'Na\u0111i i zameni',
	'Replace with': 'Zameni sa',
	'Find': 'Na\u0111i',
	'Replace all': 'Zameni sve',
	'Match case': 'Predmet za upore\u0111ivanje',
	'Prev': 'Prethodni',
	'Spellcheck': 'Provera pravopisa',
	'Finish': 'Kraj',
	'Ignore all': 'Ignori\u0161i sve',
	'Ignore': 'ignori\u0161i',
	'Insert row before': 'Ubaci red pre',
	'Rows': 'Redovi',
	'Height': 'Visina',
	'Paste row after': 'Nalepi red posle',
	'Alignment': 'Svrstavanje',
	'Column group': 'Grupa kolone',
	'Row': 'Red',
	'Insert column before': 'Ubaci kolonu pre',
	'Split cell': 'Razdvoji \u0107elije',
	'Cell padding': 'Razmak \u0107elije',
	'Cell spacing': 'Prostor \u0107elije',
	'Row type': 'Tip reda',
	'Insert table': 'ubaci tabelu',
	'Body': 'Telo',
	'Caption': 'Natpis',
	'Footer': 'Podno\u017eje',
	'Delete row': 'Obri\u0161i red',
	'Paste row before': 'Nalepi red pre',
	'Scope': 'Obim',
	'Delete table': 'Obri\u0161i tabelu',
	'Header cell': 'Visina \u0107elije',
	'Column': 'Kolona',
	'Cell': '\u0106elija',
	'Header': 'Zaglavlje',
	'Cell type': 'Tip \u0107elije',
	'Copy row': 'Kopiraj red',
	'Row properties': 'Postavke reda',
	'Table properties': 'Postavke tabele',
	'Row group': 'Grupa reda',
	'Right': 'Desno',
	'Insert column after': 'Ubaci kolonu posle',
	'Cols': 'Kolone',
	'Insert row after': 'Ubaci red posle',
	'Width': '\u0160irina',
	'Cell properties': 'Postavke \u0107elije',
	'Left': 'Levo',
	'Cut row': 'Iseci red',
	'Delete column': 'Obri\u0161i kolonu',
	'Center': 'Centar',
	'Merge cells': 'Spoji \u0107elije',
	'Insert template': 'Ubaci \u0161ablon',
	'Templates': '\u0160abloni',
	'Background color': 'Boja pozadine',
	'Text color': 'Boja tekst',
	'Show blocks': 'Prikaz blokova',
	'Show invisible characters': 'Prika\u017ei nevidljive karaktere',
	'Words: {0}': 'Re\u010di:{0}',
	'Insert': 'Umetni',
	'File': 'Datoteka',
	'Edit': 'Ure\u0111ivanje',
	'Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help':
		'Oboga\u0107en tekst. Pritisni te ALT-F9 za meni.Pritisnite ALT-F10 za traku sa alatkama.Pritisnite ALT-0 za pomo\u0107',
	'Tools': 'Alatke',
	'View': 'Prikaz',
	'Table': 'Tabela',
	'Format': 'Format',
});
